#!/usr/bin/python
#
# This script generates a 3D galaxy from a number of parameters and stores
# it in an array. You can modify this script to store the data in a database
# or whatever your purpose is. THIS script uses the data only to generate a
# PNG with a 2D view from top of the galaxy. 
#
# The algorithm used to generate the galaxy is borrowed from Ben Motz
# <motzb@hotmail.com>. The original C source code for DOS (including a 3D
# viewer) can be downloaded here:
#
# http://bits.bristol.ac.uk/motz/tep/galaxy.html
#
# Generation parameters:

# Number of stars in the core (Example: 2000)
NUMHUB   = 5000

# Number of stars in the disk (Example: 4000)
NUMDISK  = 10000

# Radius of the disk (Example: 90.0)
DISKRAD  = 20000.0

# Radius of the hub (Example: 45.0)
HUBRAD   = 10000.0

# Number of arms (Example: 3)
NUMARMS  = 3

# Tightness of winding (Example: 0.5)
ARMROTS  = 0.5

# Arm width in degrees (Not affected by number of arms or rotations)
# Exammple: 65.0
ARMWIDTH = 65.0

# Maximum depth of arms (Example: 2.0)
MAXDISKZ = 450.0

# Maximum depth of core (Example: 16.0)
MAXHUBZ  = 3500.0

# Maximum outlier distance from arms (Example: 25.0)
FUZZ     = 25.0


# X and Y size of the created PNG
PNGSIZE    = 800

# Background color of the created PNG
PNGBGCOLOR = ( 0, 0, 0 )

# Foreground color of the created PNG
PNGCOLOR   = ( 255, 255, 255 )

# PNG frame size
PNGFRAME   = 50

VOWELS = [
    'a','e','i','o','u','y'
]

import string

#CONSONANTS = set(string.ascii_lowercase) set(VOWELS)
#CONSONANTS += [
#    'ng','sh','th','ch',
#]



alphabet = [
        'Alpha',
        'Beta',
        'Gamma',
        'Delta',
        'Epsilon',
        'Zeta',
        'Eta',
        'Theta',
        'Iota',
        'Kappa',
        'Lambda',
        'Mu',
        'Nu',
]


clusternames = [
        'Antilae',
        'Draconis',
        'Ophiuchi',
        'Mersenne',
        'Pavonis',
        'Pegasi',
        'Serpentis',
        'Vulpeculae',
        'Ceti',
        'Gruis',
        'Cygnus',
        'Tauri',
        'Virginis',
        'Illuminati',
        'Herculis',
        'Krueger',
        'Gorno',
        'Sextantis',
        'Luyten',
        'Sctui',
        'Persei',
        'Arae',
        'Reticuli',
        'Cancri',
        'Eridani',
        'Leonis',
        'Geminorum',
        'Lyncis',
        'Cerenkov',
        'Scorpii',
        'Vitalis',
        'Bootis',
]

lonernames = [
        'Sol',
        'Altair',
        'Arcturus',
        'Aldebaran',
        'Hyperion',
        'Pollux',
        'Metis',
        'Regulus',
        'Vela',
        'Rigel',
        'Fomalhaut',
        'Vega',
        'Sirius',
        'Betelgeuse',
        'Mizar',
        'Deneb',
        'Procyon',
]


# ---------------------------------------------------------------------------

import random
import time
import math
import sys

from assam.util import dist


class Star(object):
    x = 0.0
    y = 0.0
    z = 0.0
    spectral = None
    size = None
    luminosity = None
    mass = None
    name = None

    def __init__(_, x,y,name):
        _.x = x
        _.y = y
        _.name = name


def overlap(pos, stars, minimum):
#    return False
    for s in stars:
        try:
            x = s.x
            y = s.y
        except AttributeError:
            x, y = s

        distance = dist(pos, (x, y))
        if distance <= minimum:
            return True
    return False



# num_clusters
# cluster_size_max
# cluster_size_min
# cluster_stars_min
# cluster_stars_max
# generate clusters
# pepper with unclustered stars

def generate_sector(seed=None):
    total_stars = 100
    minimum_star_separation = 3
    
    clusters_num = (20,30)
    #cluster_size = (8, 24)
    cluster_stars = (2, 8)

    bounds = ((-200,200), (200,-200))

    x_bounds = bounds[0][0], bounds[1][0]
    y_bounds = bounds[1][1], bounds[0][1]
    
    if not seed:
        seed = time.time()

    random.seed(seed)

    random.shuffle(clusternames)
    random.shuffle(lonernames)

    clusters = []
    stars = []
    stars_made = 0

    randfunc = random.uniform

    for i in range(0, randfunc(*clusters_num)):
        # generate cluster name

        # generate cluster origin
        overlapping = True
        while overlapping:
            origin = randfunc(*x_bounds), randfunc(*y_bounds)
            # determine cluster size and number of stars
            #radius = randfunc(*cluster_size)
            num_stars = int(randfunc(*cluster_stars))
            radius = num_stars * 3

            overlapping = overlap(origin, clusters, radius)

        clustername = clusternames.pop()

        clusters.append(origin)

        
        print clustername, "cluster created at", `origin`, "with size", radius, " and ", num_stars, "stars..."

        for i in range(0, num_stars):
            # generate position for each star
            x = 0
            y = 0
            overlapping = True
            while x < x_bounds[0] or x > x_bounds[1] or \
                  y < y_bounds[0] or y > y_bounds[1] or \
                  overlapping:
                x = randfunc(origin[0] - radius, origin[0] + radius)
                y = randfunc(origin[1] - radius, origin[1] + radius)
                overlapping = overlap((x,y), stars, minimum_star_separation)

            # generate name
            name = alphabet[i] +" "+ clustername 
            stars.append(Star(x,y, name))
            stars_made += 1
            #print "star created at", `(x,y)`

        # generate non-clustered stars
        while stars_made < total_stars:
            x = 0
            y = 0
            overlapping = True
            while x < x_bounds[0] or x > x_bounds[1] or \
                  y < y_bounds[0] or y > y_bounds[1] or \
                  overlapping:
                x = randfunc(*x_bounds)
                y = randfunc(*y_bounds)
                overlapping = overlap((x,y), stars, minimum_star_separation)

            try:
                name = lonernames.pop()
            except IndexError:
                name = "TooMany!"

            stars.append(Star(x,y, name))
            stars_made += 1
            print name, "created at", `(x,y)`

    return stars


probabilities = {
        'star_size': [
            (1,1,'giant'),
            (2,23,'subgiant'),
            (24,76,'main_sequence'),
            (77,86,'white_dwarf'),
            (87,99,'brown_dwarf'),
            (100,100,'special'),
        ],
        'star_spectral': [
            (1,1,'giant'),
            (2,2,'A'),
            (3,5,'F'),
            (6,13,'G'),
            (14,27,'K'),
            (28,76,'M'),
            (77,86,'white_dwarf'),
            (87,99,'brown_dwarf'),
            (100,100,'special'),
        ],
        'star_binary' : [
            (1,69,False),
            (70,100,True),
        ],
        'nebula_coverage' : [
            (1,20,True),
            (21,100,False),
        ],
}

def generateStars():
    stars = []

    # omega is the separation (in degrees) between each arm
    # Prevent div by zero error:
    if NUMARMS:
        omega = 360.0 / NUMARMS
    else:
        omega = 0.0
    i = 0
    while i < NUMDISK:
        # Choose a random distance from center
        dist = HUBRAD + random.random() * DISKRAD

        # This is the 'clever' bit, that puts a star at a given distance
        # into an arm: First, it wraps the star round by the number of
        # rotations specified.  By multiplying the distance by the number of
        # rotations the rotation is proportional to the distance from the
        # center, to give curvature
        theta = ( ( 360.0 * ARMROTS * ( dist / DISKRAD ) )
        
            # Then move the point further around by a random factor up to
            # ARMWIDTH
                + random.random() * ARMWIDTH
                
            # Then multiply the angle by a factor of omega, putting the
            # point into one of the arms
                #+ (omega * random.random() * NUMARMS )
                + omega * random.randrange( 0, NUMARMS )
                
            # Then add a further random factor, 'fuzzin' the edge of the arms
                + random.random() * FUZZ * 2.0 - FUZZ
                #+ random.randrange( -FUZZ, FUZZ )
            )
            
        # Convert to cartesian
        x = math.cos( theta * math.pi / 180.0 ) * dist
        y = math.sin( theta * math.pi / 180.0 ) * dist
        z = random.random() * MAXDISKZ * 2.0 - MAXDISKZ

        # Add star to the stars array            
        stars.append( ( x, y ,z ) )

        # Process next star
        i = i + 1
    
    # Now generate the Hub. This places a point on or under the curve
    # maxHubZ - s d^2 where s is a scale factor calculated so that z = 0 is
    # at maxHubR (s = maxHubZ / maxHubR^2) AND so that minimum hub Z is at
    # maximum disk Z. (Avoids edge of hub being below edge of disk)
    
    scale = MAXHUBZ / ( HUBRAD * HUBRAD )
    i = 0
    while i < NUMHUB:
        # Choose a random distance from center
        dist = random.random() * HUBRAD
      
        # Any rotation (points are not on arms)
        theta = random.random() * 360
        
        # Convert to cartesian
        x = math.cos( theta * math.pi / 180.0) * dist
        y = math.sin( theta * math.pi / 180.0) * dist
        z = ( random.random() * 2 - 1 ) * ( MAXHUBZ - scale * dist * dist )
        
        # Add star to the stars array
        stars.append( ( x, y, z ) )
    
        # Process next star
        i = i + 1

    return stars

def drawToPNG( filename ):
    image = Image.new( "RGB", ( PNGSIZE, PNGSIZE ), PNGBGCOLOR )
    draw = ImageDraw.Draw( image )
    
    # Find maximal star distance
    max = 0
    for ( x, y, z ) in stars:
        if abs(x) > max: max = x
        if abs(y) > max: max = y
        if abs(z) > max: max = z
    
    # Calculate zoom factor to fit the galaxy to the PNG size
    factor = float( PNGSIZE - PNGFRAME * 2 ) / ( max * 2 )
    for ( x, y, z ) in stars:
        sx = factor * x + PNGSIZE / 2
        sy = factor * y + PNGSIZE / 2
        draw.point( ( sx, sy ), fill = PNGCOLOR )
      
    # Save the PNG
    image.save( filename )


def main():
    seed = None

    if not seed:
        seed = time.time()

    random.seed(seed)

    # Generate the galaxy          
    #generateStars()
    fullofstars = generate_sector(seed)

    # Save the galaxy as PNG to galaxy.png
    #drawToPNG( "galaxy.png" )

    print "seed was:", seed


